@@ -67,7 +67,7 @@ Returns the average for properties which match the number of bedrooms, property
         num_beds => 3                   # integer
         per_sqm => 1,                   # price returned per square metre
     );
-    my $average_price = $metadata->get_average_price_by_beds(%options);
+    my $average_price = $metadata->get_average_price(%options);
 
 Rent prices are monthly. Prices for the UK are in GBP. Prices for Spain, Italy and Germany are in Euros. The earliest date available is October 2007.
 
@@ -191,7 +191,9 @@ Copyright (C) 2009 Lokku Ltd.
 
 =head1 Author
 
-Alex Balhatchet (kaoru at slackwise dot net), Yoav Felberbaum (perl at mrdini dot com), Alistair Francis (cpan at alizta dot com)
+Alex Balhatchet (alex@lokku.com)
+
+Patches supplied by Yoav Felberbaum and Alistair Francis.
 
 =cut
 
